@@ -1,8 +1,8 @@
-__version__ = "3.0.14"
+__version__ = "3.1.0"
 from janda.pururin import Pururin
 from janda.nhentai import Nhentai
 from janda.hentaifox import Hentaifox
 from janda.hentai2read import Hentai2read
 from janda.simply_hentai import SimplyHentai
 from janda.asmhentai import Asmhentai
-from janda.utils.parser import resolve
+from janda.utils.client import resolve
