@@ -1,12 +1,11 @@
-import requests
-import json
-from janda.utils.parser import *
+from janda.utils.client import *
+from janda.utils.request import request
 
-BASE_URL = Api()
+Janda = Api()
 
 
 class Pururin(object):
-    """Pururin API wrapper
+    """Jandapress Pururin API
 
     Methods
     -------
@@ -20,36 +19,13 @@ class Pururin(object):
         Searches doujin by tags / artist / character / parody or group
     """
 
-    @staticmethod
-    def better_object(parser: dict):
-        """Converts the json object to a more readable object.
-
-        Parameters
-        ----------
-        parser : dict
-            The json object.
-        """
-        return json.dumps(parser, sort_keys=True, indent=4)
-
-    @staticmethod
-    def auto_space(string: str):
-        """Automatically adds spaces for GET requests
-
-        Parameters
-        ----------
-        string : str
-            The string to be formatted.
-        """
-
-        return string.replace(" ", "+")
-
     def __init__(self, api_key: str = ""):
         """Initializes the Pururin.
 
         Parameters
         ----------
         api_key : str
-            scathach.dev API key (optional)
+            scathach.id API key (optional)
         """
         if api_key == "":
             self.api_key = None
@@ -57,7 +33,7 @@ class Pururin(object):
             self.api_key = api_key
         self.specs = {"api_key": self.api_key}
 
-    async def get(self, book: int):
+    async def get(self, book: int) -> str:
         """Get doujin from id
 
         path: https://pururin.to/gallery/61119
@@ -74,24 +50,15 @@ class Pururin(object):
 
         Returns
         -------
-        dict
-            The book object that represents the specific id response.
+        str
+            reparsed json as string
         """
 
-        self.specs["book"] = book
+        self.book = str(book)
+        data = await request(Janda.pururin + Janda.endpoint_book, self.book)
+        return better_object(data)
 
-        try:
-            book = int(book)
-        except ValueError:
-            raise ValueError("Book must be an int")
-
-        data = requests.get(BASE_URL.pururin + "/get", params=self.specs)
-        if data.json()["data"]["title"] == "":
-            raise ValueError("No results found")
-
-        return better_object(data.json())
-
-    async def search(self, query: str, page: int = 1, sort: str = "newest"):
+    async def search(self, query: str, page: int = 1, sort: str = "newest") -> str:
         """Search doujin by tags / artist / character / parody or group
 
         Parameters
@@ -112,8 +79,8 @@ class Pururin(object):
 
         Returns
         -------
-        dict
-            The list object that represents the doujin response
+        str
+            reparsed json as string
         """
 
         if sort not in [
@@ -128,30 +95,22 @@ class Pururin(object):
                 "Sort must be one of newest, most-popular, highest-rated, most-viewed, title, random"
             )
 
-        self.specs["key"] = query
-        self.specs["page"] = page
-        self.specs["sort"] = sort
+        self.query = query
+        self.page = page
+        self.sort = sort
+        self.req = str(self.query + "&page=" +
+                       str(self.page) + "&sort=" + self.sort)
 
-        data = requests.get(BASE_URL.pururin + "/search", params=self.specs)
+        data = await request(Janda.pururin + Janda.endpoint_search, self.req)
+        return better_object(data)
 
-        if len(data.json()["data"]) == 0:
-            raise ValueError("No results found")
-
-        if data.status_code != 200:
-            raise ValueError(
-                "Request failed with status code {}".format(data.status_code)
-            )
-
-        return better_object(data.json())
-
-    async def get_random(self):
+    async def get_random(self) -> str:
         """Gets random doujin on pururin
 
         Returns
         -------
-        dict
-            The book object that represents the random doujin response.
+        str
+            reparsed json as string
         """
-        data = requests.get(BASE_URL.pururin + "/random", params=self.specs)
-
-        return better_object(data.json())
+        data = await request(Janda.pururin + Janda.endpoint_random)
+        return better_object(data)
