@@ -1,6 +1,6 @@
 import requests
 import json
-from .utils.parser import *
+from .utils.client import *
 
 BASE_URL = Api()
 
@@ -20,7 +20,7 @@ class SimplyHentai(object):
         Parameters
         ----------
         api_key : str
-            scathach.dev API key (optional)
+            scathach.id API key (optional)
         """
         if api_key == "":
             self.api_key = None
