@@ -1,7 +1,7 @@
-import json
 import requests
-from janda.utils.parser import list_api
+from janda.utils.client import list_api
 
 for api in list_api():
     r = requests.get(api)
-    print(api, r.status_code)
\ No newline at end of file
+    print(api, r.status_code)
+    
\ No newline at end of file
